// 防止重复执行
if (typeof window.fetchAnnouncement !== 'function') {

    // 添加完整 CSS 样式
    const style = document.createElement('style');
    style.textContent = `
        .modern-modal-overlay {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.4);
            display: flex;
            justify-content: center;
            align-items: center;
            z-index: 1000;
            font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif;
            transition: opacity 0.3s ease;
        }
        .modern-modal-container {
            background: #FFFFFF;
            border-radius: 12px;
            width: 90%;
            max-width: 400px;
            box-shadow: 0 10px 25px rgba(0, 0, 0, 0.1);
            overflow: hidden;
            animation: modalFadeIn 0.3s ease-out;
        }
        .modern-modal-header {
            display: flex;
            align-items: center;
            padding: 12px 16px;
            background: #f8f8f8;
            border-bottom: 1px solid #eee;
        }
        .modern-modal-dots {
            display: flex;
            gap: 6px;
            margin-right: 8px;
        }
        .dot {
            width: 12px;
            height: 12px;
            border-radius: 50%;
        }
        .dot.red { background: #FF5F56; }
        .dot.yellow { background: #FFBD2E; }
        .dot.green { background: #27C93F; }
        .modern-modal-title {
            font-size: 14px;
            color: #555;
            font-weight: 500;
        }
        .modern-modal-body {
            padding: 24px 20px;
        }
        .modern-modal-top {
            display: flex;
            align-items: center;
            margin-bottom: 12px;
        }
        .modern-modal-version {
            margin: 0;
            color: #333;
            font-size: 18px;
            font-weight: 600;
            line-height: 1.5;
        }
        .modern-modal-updates {
            white-space: pre-wrap;
            font-size: 16px;
            color: #444;
            margin: 0;
            padding: 0;
            max-height: 200px;
            overflow-y: auto;
            line-height: 1.6;
        }
        .modern-modal-footer {
            display: flex;
            justify-content: flex-end;
            padding: 12px 16px;
            background: #f8f8f8;
            border-top: 1px solid #eee;
            gap: 8px;
        }
        .modern-modal-btn {
            padding: 8px 16px;
            border-radius: 6px;
            border: none;
            font-size: 14px;
            font-weight: 500;
            cursor: pointer;
            transition: all 0.2s ease;
        }
        .modern-modal-btn.primary {
            background: #0098dc;
            color: white;
        }
        .modern-modal-btn.primary:hover {
            background: #007bb5;
        }
        .modern-modal-btn.secondary {
            background: transparent;
            color: #666;
        }
        .modern-modal-btn.secondary:hover {
            background: rgba(0, 0, 0, 0.05);
        }
        @media (prefers-color-scheme: dark) {
            .modern-modal-container {
                background: #2a2a2a;
                box-shadow: 0 10px 25px rgba(0, 0, 0, 0.3);
            }
            .modern-modal-header {
                background: #333;
                border-bottom-color: #444;
            }
            .modern-modal-title {
                color: #ccc;
            }
            .modern-modal-version {
                color: #eee;
            }
            .modern-modal-updates {
                color: #bbb;
            }
            .modern-modal-footer {
                background: #333;
                border-top-color: #444;
            }
            .modern-modal-btn.secondary {
                color: #ccc;
            }
            .modern-modal-btn.secondary:hover {
                background: rgba(255, 255, 255, 0.1);
            }
        }
        @keyframes modalFadeIn {
            from {
                opacity: 0;
                transform: translateY(20px);
            }
            to {
                opacity: 1;
                transform: translateY(0);
            }
        }
    `;
    document.head.appendChild(style);

    // 显示弹窗的函数
    function showModernModal(title, content, isMandatory = false) {
        const overlay = document.createElement('div');
        overlay.className = 'modern-modal-overlay';

        const container = document.createElement('div');
        container.className = 'modern-modal-container';

        const header = document.createElement('div');
        header.className = 'modern-modal-header';
        
        const dots = document.createElement('div');
        dots.className = 'modern-modal-dots';
        dots.innerHTML = `
            <div class="dot red"></div>
            <div class="dot yellow"></div>
            <div class="dot green"></div>
        `;
        
        const headerTitle = document.createElement('div');
        headerTitle.className = 'modern-modal-title';
        headerTitle.textContent = "公告"; // 固定显示“公告”
        
        header.appendChild(dots);
        header.appendChild(headerTitle);

        const body = document.createElement('div');
        body.className = 'modern-modal-body';
        
        const top = document.createElement('div');
        top.className = 'modern-modal-top';
        
        const version = document.createElement('div');
        version.className = 'modern-modal-version';
        
        const updates = document.createElement('p');
        updates.className = 'modern-modal-updates';
        updates.textContent = content;
        
        top.appendChild(version);
        body.appendChild(top);
        body.appendChild(updates);

        const footer = document.createElement('div');
        footer.className = 'modern-modal-footer';

        if (!isMandatory) {
            const secondaryBtn = document.createElement('button');
            secondaryBtn.className = 'modern-modal-btn secondary';
            secondaryBtn.textContent = '关闭';
            secondaryBtn.onclick = () => overlay.remove();
            
            const primaryBtn = document.createElement('button');
            primaryBtn.className = 'modern-modal-btn primary';
            primaryBtn.textContent = '确定';
            primaryBtn.onclick = () => overlay.remove();
            
            footer.appendChild(secondaryBtn);
            footer.appendChild(primaryBtn);

            overlay.addEventListener('click', (e) => {
                if (e.target === overlay) {
                    overlay.remove();
                }
            });
        } else {
            const notice = document.createElement('div');
            notice.style.color = '#666';
            notice.style.fontSize = '14px';
            notice.textContent = '正在维护…';
            footer.appendChild(notice);
        }

        container.appendChild(header);
        container.appendChild(body);
        container.appendChild(footer);
        overlay.appendChild(container);
        document.body.appendChild(overlay);
    }

    // 接口定义
    const PRIMARY_API = "https://api.kuleu.com/api/qqcollection?url=https://sharechain.qq.com/731f08793c54450e62e2d8f30655570c";
    const BACKUP_API_1 = "https://api.suyanw.cn/api/qq/qqsc.php?url=https://sharechain.qq.com/731f08793c54450e62e2d8f30655570c";
    const BACKUP_API_2 = "https://api.pearktrue.cn/api/qq/qqsc.php?url=https://sharechain.qq.com/731f08793c54450e62e2d8f30655570c";
    const BACKUP_API_3 = "https://api.kuleu.com/api/qqcollection?url=https://sharechain.qq.com/731f08793c54450e62e2d8f30655570c";

    // 获取公告数据的函数
    async function fetchUpdateData(apiUrl) {
        try {
            const response = await fetch(apiUrl);
            if (!response.ok) throw new Error(`HTTP错误: ${response.status}`);
            const data = await response.json();
            return data;
        } catch (error) {
            console.error(`接口 ${apiUrl} 请求失败:`, error.message);
            throw error;
        }
    }

    // 获取公告函数
    async function fetchAnnouncement() {
        const lastPopupTimeKey = "lastPopupTime";
        const lastContentKey = "lastAnnouncementContent";

        let result;
        const apis = [PRIMARY_API, BACKUP_API_1, BACKUP_API_2, BACKUP_API_3];
        for (let i = 0; i < apis.length; i++) {
            try {
                result = await fetchUpdateData(apis[i]);
                const successCode = (i === 1) ? 1 : 200;
                if (result.code !== successCode) {
                    throw new Error(`接口返回错误代码: ${result.code}`);
                }
                console.log(`成功获取数据来自接口 ${i + 1}:`, result);
                break;
            } catch (error) {
                console.warn(`接口 ${i + 1} 失败:`, error.message);
                if (i === apis.length - 1) {
                    console.error("所有接口获取失败");
                    return;
                }
            }
        }

        if (!result || !result.data || !result.data.summary) {
            console.error("数据结构无效:", result);
            return;
        }

        try {
            const rawTitle = result.data.summary.title?.trim(); // 不设置默认值
            const brief = result.data.summary.brief?.trim() || "";
            const currentContent = `${rawTitle}|${brief}`;

            const lastPopupTime = localStorage.getItem(lastPopupTimeKey);
            const lastContent = localStorage.getItem(lastContentKey) || "";

            const formattedBrief = brief.replace(/(\d+\.\s*)/g, '\n$1').trim();

            // 如果没有标题，不显示弹窗
            if (!rawTitle || rawTitle === "") {
                console.log("标题为空，不显示弹窗");
                return;
            }

            if (brief) {
                const isMandatory = rawTitle === "公告1";
                if (isMandatory) {
                    // 强制弹窗：每次显示，标题固定为“公告”
                    showModernModal("公告", formattedBrief, true);
                } else if (!lastPopupTime || lastContent !== currentContent) {
                    // 普通弹窗：仅首次或内容变更时显示，标题固定为“公告”
                    showModernModal("公告", formattedBrief, false);
                    localStorage.setItem(lastPopupTimeKey, new Date().getTime());
                    localStorage.setItem(lastContentKey, currentContent);
                } else {
                    console.log("普通公告无需显示：内容未变更");
                }
            } else {
                console.log("内容为空，不显示弹窗");
            }
        } catch (error) {
            console.error("处理公告数据失败:", error);
        }
    }

    // 页面加载完成后请求公告
    window.onload = fetchAnnouncement;
}