// 更新地址
const updateUrl = 'https://tfgjx.lanzoui.com/b03r523lc';

// 接口定义
const PRIMARY_API = 'https://api.kuleu.com/api/qqcollection?url=https://sharechain.qq.com/fba50ba12dc84bc3aca0ae519eac8da1'; // 主接口
const BACKUP_API_1 = 'https://api.suyanw.cn/api/qq/qqsc.php?url=https://sharechain.qq.com/fba50ba12dc84bc3aca0ae519eac8da1'; // 备用接口1
const BACKUP_API_2 = 'https://api.kuleu.com/api/qqcollection?url=https://sharechain.qq.com/fba50ba12dc84bc3aca0ae519eac8da1'; // 备用接口2
const BACKUP_API_3 = 'https://api.pearktrue.cn/api/qq/qqsc.php?url=https://sharechain.qq.com/fba50ba12dc84bc3aca0ae519eac8da1'; // 备用接口3（新增）

// 测试开关：设为 true 以模拟主接口失败
const SIMULATE_PRIMARY_FAILURE = false; // 改为 true 来测试备用接口

// 从标题中提取版本号
function extractVersion(title) {
    if (typeof title !== "string") {
        title = title.toFixed(1); // 如果不是字符串，转换为小数点后一位的字符串
    }
    console.log("服务器版本:", title);
    const match = title.match(/^(\d+\.\d+)$/);
    return match ? match[1] : null;
}

// 比较版本号
function compareVersions(current, latest) {
    const c = current.split('.').map(Number);
    const l = latest.split('.').map(Number);
    return c[0] < l[0] || (c[0] === l[0] && c[1] < l[1]) ? -1 : c[0] > l[0] || c[1] > l[1] ? 1 : 0;
}

// 获取更新数据
async function fetchUpdateData(apiUrl) {
    if (SIMULATE_PRIMARY_FAILURE && apiUrl === PRIMARY_API) {
        throw new Error('模拟主接口失败'); // 测试用：强制主接口失败
    }
    const response = await fetch(apiUrl);
    const data = await response.json();
    return data;
}

// 显示调整后的弹窗
function showUpdateModal(latestVersion, updateDetails) {
    // 移除已有模态框
    const existingModal = document.querySelector('.modern-modal-overlay');
    if (existingModal) existingModal.remove();

    // 格式化更新内容，确保每个编号项换行
    const formattedUpdates = updateDetails.replace(/(\d+\.\s*)/g, '\n$1').trim();

    // 创建模态框
    const modal = document.createElement('div');
    modal.className = 'modern-modal-overlay';
    modal.innerHTML = `
        <div class="modern-modal-container">
            <div class="modern-modal-header">
                <div class="modern-modal-dots">
                    <span class="dot red"></span>
                    <span class="dot yellow"></span>
                    <span class="dot green"></span>
                </div>
                <div class="modern-modal-title">更新提示</div>
            </div>
            <div class="modern-modal-body">
                <div class="modern-modal-top">
                    <img src="favicon.png" class="modern-modal-icon" alt="favicon">
                    <p class="modern-modal-version">发现新版本 <span class="version-badge">${latestVersion}</span></p>
                </div>
                <pre class="modern-modal-updates">${formattedUpdates}</pre>
            </div>
            <div class="modern-modal-footer">
                <button class="modern-modal-btn secondary" id="cancelButton">立即退出</button>
                <button class="modern-modal-btn primary" id="confirmButton">立即更新</button>
            </div>
        </div>
    `;

    // 添加样式
    const style = document.createElement('style');
    style.textContent = `
        .modern-modal-overlay {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.4);
            display: flex;
            justify-content: center;
            align-items: center;
            z-index: 1000;
            font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif;
            transition: opacity 0.3s ease;
        }
        .modern-modal-container {
            background: #FFFFFF;
            border-radius: 12px;
            width: 90%;
            max-width: 400px;
            box-shadow: 0 10px 25px rgba(0, 0, 0, 0.1);
            overflow: hidden;
            animation: modalFadeIn 0.3s ease-out;
        }
        .modern-modal-header {
            display: flex;
            align-items: center;
            padding: 12px 16px;
            background: #f8f8f8;
            border-bottom: 1px solid #eee;
        }
        .modern-modal-dots {
            display: flex;
            gap: 6px;
            margin-right: 8px;
        }
        .dot {
            width: 12px;
            height: 12px;
            border-radius: 50%;
        }
        .dot.red { background: #FF5F56; }
        .dot.yellow { background: #FFBD2E; }
        .dot.green { background: #27C93F; }
        .modern-modal-title {
            font-size: 14px;
            color: #555;
            font-weight: 500;
        }
        .modern-modal-body {
            padding: 24px 20px;
        }
        .modern-modal-top {
            display: flex;
            align-items: center;
            margin-bottom: 12px;
        }
        .modern-modal-icon {
            width: 48px;
            height: 48px;
            margin-right: 16px;
            flex-shrink: 0;
            border-radius: 10px;
        }
        .modern-modal-version {
            margin: 0;
            color: #333;
            font-size: 16px;
            font-weight: 500;
            line-height: 1.5;
        }
        .modern-modal-updates {
            white-space: pre-wrap;
            font-size: 14px;
            color: #666;
            margin: 0;
            padding: 0;
            max-height: 200px;
            overflow-y: auto;
        }
        .version-badge {
            display: inline-block;
            background: #0098dc;
            color: white;
            padding: 2px 8px;
            border-radius: 10px;
            font-size: 14px;
            font-weight: 500;
        }
        .modern-modal-footer {
            display: flex;
            justify-content: flex-end;
            padding: 12px 16px;
            background: #f8f8f8;
            border-top: 1px solid #eee;
            gap: 8px;
        }
        .modern-modal-btn {
            padding: 8px 16px;
            border-radius: 6px;
            border: none;
            font-size: 14px;
            font-weight: 500;
            cursor: pointer;
            transition: all 0.2s ease;
        }
        .modern-modal-btn.primary {
            background: #0098dc;
            color: white;
        }
        .modern-modal-btn.primary:hover {
            background: #007bb5;
        }
        .modern-modal-btn.secondary {
            background: transparent;
            color: #666;
        }
        .modern-modal-btn.secondary:hover {
            background: rgba(0, 0, 0, 0.05);
        }
        @media (prefers-color-scheme: dark) {
            .modern-modal-container {
                background: #2a2a2a;
                box-shadow: 0 10px 25px rgba(0, 0, 0, 0.3);
            }
            .modern-modal-header {
                background: #333;
                border-bottom-color: #444;
            }
            .modern-modal-title {
                color: #ccc;
            }
            .modern-modal-version {
                color: #eee;
            }
            .modern-modal-updates {
                color: #aaa;
            }
            .modern-modal-footer {
                background: #333;
                border-top-color: #444;
            }
            .modern-modal-btn.secondary {
                color: #ccc;
            }
            .modern-modal-btn.secondary:hover {
                background: rgba(255, 255, 255, 0.1);
            }
        }
        @keyframes modalFadeIn {
            from { opacity: 0; transform: translateY(20px); }
            to { opacity: 1; transform: translateY(0); }
        }
    `;
    document.head.appendChild(style);

    // 添加模态框到页面
    document.body.appendChild(modal);

    // 点击"更新"跳转更新地址
    document.getElementById('confirmButton').onclick = () => {
        webapp.browse(updateUrl);
    };

    // 点击"取消"退出应用
    document.getElementById('cancelButton').onclick = () => {
        webapp.secede();
    };

    // 禁止点击空白处关闭
    modal.onclick = (e) => {
        if (e.target === modal) {
            e.stopPropagation();
            return;
        }
    };

    // 禁用返回键和右键
    webapp.revert("");
    window.oncontextmenu = () => false;
}

// 检查更新
async function checkForUpdate() {
    try {
        const currentVersion = webapp.getpage();
        console.log("当前版本号:", currentVersion);

        if (!currentVersion || !extractVersion(currentVersion)) {
            throw new Error('无法获取当前版本号或格式错误');
        }

        let data;
        try {
            // 首先尝试主接口
            data = await fetchUpdateData(PRIMARY_API);
            if (data.code !== 200) throw new Error('主接口返回错误代码');
            console.log('主接口响应:', data);
        } catch (primaryError) {
            console.warn('主接口请求失败:', primaryError.message);
            // 主接口失败，尝试备用接口1
            try {
                data = await fetchUpdateData(BACKUP_API_1);
                if (data.code !== 1) throw new Error('备用接口1返回错误代码');
                console.log('备用接口1响应:', data);
            } catch (backupError1) {
                console.warn('备用接口1请求失败:', backupError1.message);
                // 备用接口1失败，尝试备用接口2
                try {
                    data = await fetchUpdateData(BACKUP_API_2);
                    if (data.code !== 200) throw new Error('备用接口2返回错误代码');
                    console.log('备用接口2响应:', data);
                } catch (backupError2) {
                    console.warn('备用接口2请求失败:', backupError2.message);
                    // 备用接口2失败，尝试备用接口3
                    try {
                        data = await fetchUpdateData(BACKUP_API_3);
                        if (data.code !== 200) throw new Error('备用接口3返回错误代码');
                        console.log('备用接口3响应:', data);
                    } catch (backupError3) {
                        console.error('备用接口3也失败:', backupError3.message);
                        throw new Error('所有接口均不可用');
                    }
                }
            }
        }

        // 处理数据
        const latestVersion = extractVersion(data.data.summary.title);
        if (!latestVersion) throw new Error('服务器版本格式错误');

        // 直接使用原始 brief 字符串，交给 showUpdateModal 处理换行
        const updateDetails = data.data.summary.brief;

        const comparison = compareVersions(currentVersion, latestVersion);

        if (comparison === -1) {
            showUpdateModal(latestVersion, updateDetails);
        } else if (comparison === 1) {
            alert('非官方版本…');
            webapp.secede();
        } else {
            console.log('当前版本是最新的，无需更新');
        }
    } catch (error) {
        console.error('检查更新失败:', error.message);
        console.log('所有接口失效，直接放行');
    }
}

// 在页面加载时执行检查
document.addEventListener('DOMContentLoaded', checkForUpdate);